==> ejc-mdm-api-3.0.0-20220315.061006-23-sources.jar: com/ejianc/foundation/mdm/vo/DataModelVO.java <==
package com.ejianc.foundation.mdm.vo;

import java.util.ArrayList;
import java.util.List;

import com.ejianc.framework.skeleton.template.BaseVO;

public class DataModelVO extends BaseVO {

	private static final long serialVersionUID = 1L;

	/**
	 * 数据模型分类ID
	 */
	private Long categoryId;

	private String categoryName;

	/**
	 * 父ID
	 */
	private Long parentId;

	/**
	 * 数据模型编码
	 */
	private String modelCode;

	/**
	 * 数据模型名称
	 */
	private String modelName;

	/**
	 * 数据模型排序
	 */
	private Integer sequence;

	/**
	 * 是否发布： 1已发布， 0未发布
	 */
	private Integer publishFlag;

	private List<DataModelItemVO> dataModelItemVos = new ArrayList<DataModelItemVO>();
	
	private List<DataModelVO> children;

	/**
	 * 数据模型名称(树节点显示使用)
	 */
	private Long key;

	/**
	 * 数据模型名称(树节点显示使用)
	 */
	private String title;

	public Long getCategoryId() {
		return categoryId;
	}

	public void setCategoryId(Long categoryId) {
		this.categoryId = categoryId;
	}

	public String getCategoryName() {
		return categoryName;
	}

	public void setCategoryName(String categoryName) {
		this.categoryName = categoryName;
	}

	public Long getParentId() {
		return parentId;
	}

	public void setParentId(Long parentId) {
		this.parentId = parentId;
	}

	public String getModelCode() {
		return modelCode;
	}

	public void setModelCode(String modelCode) {
		this.modelCode = modelCode;
	}

	public String getModelName() {
		return modelName;
	}

	public void setModelName(String modelName) {
		this.modelName = modelName;
	}

	public Integer getSequence() {
		return sequence;
	}

	public void setSequence(Integer sequence) {
		this.sequence = sequence;
	}

	public Integer getPublishFlag() {
		return publishFlag;
	}

	public void setPublishFlag(Integer publishFlag) {
		this.publishFlag = publishFlag;
	}

	public List<DataModelItemVO> getDataModelItemVos() {
		return dataModelItemVos;
	}

	public void setDataModelItemVos(List<DataModelItemVO> dataModelItemVos) {
		this.dataModelItemVos = dataModelItemVos;
	}

	public List<DataModelVO> getChildren() {
		return children;
	}

	public void setChildren(List<DataModelVO> children) {
		this.children = children;
	}

	public String getTitle() {
		return modelName;
	}

	public Long getKey() {
		return key;
	}

	public void setKey(Long key) {
		this.key = key;
	}
	
}

==> ejc-mdm-api-3.0.0-20251017.040949-196-sources.jar: com/ejianc/foundation/mdm/vo/DataModelVO.java <==
package com.ejianc.foundation.mdm.vo;

import java.util.ArrayList;
import java.util.List;

import com.ejianc.framework.skeleton.template.BaseVO;

public class DataModelVO extends BaseVO {

	private static final long serialVersionUID = 1L;

	/**
	 * 数据模型分类ID
	 */
	private Long categoryId;

	private String categoryName;

	/**
	 * 父ID
	 */
	private Long parentId;

	/**
	 * 数据模型编码
	 */
	private String modelCode;

	/**
	 * 数据模型名称
	 */
	private String modelName;

	/**
	 * 同步地址
	 */
	private String syncAddress;

	/**
	 * 数据模型排序
	 */
	private Integer sequence;

	/**
	 * 是否发布： 1已发布， 0未发布
	 */
	private Integer publishFlag;

	private List<DataModelItemVO> dataModelItemVos = new ArrayList<DataModelItemVO>();

	private List<DataModelVO> children;

	/**
	 * 数据模型名称(树节点显示使用)
	 */
	private Long key;

	/**
	 * 数据模型名称(树节点显示使用)
	 */
	private String title;

	public Long getCategoryId() {
		return categoryId;
	}

	public void setCategoryId(Long categoryId) {
		this.categoryId = categoryId;
	}

	public String getCategoryName() {
		return categoryName;
	}

	public void setCategoryName(String categoryName) {
		this.categoryName = categoryName;
	}

	public Long getParentId() {
		return parentId;
	}

	public void setParentId(Long parentId) {
		this.parentId = parentId;
	}

	public String getModelCode() {
		return modelCode;
	}

	public void setModelCode(String modelCode) {
		this.modelCode = modelCode;
	}

	public String getModelName() {
		return modelName;
	}

	public void setModelName(String modelName) {
		this.modelName = modelName;
	}

	public String getSyncAddress() {
		return syncAddress;
	}

	public void setSyncAddress(String syncAddress) {
		this.syncAddress = syncAddress;
	}

	public Integer getSequence() {
		return sequence;
	}

	public void setSequence(Integer sequence) {
		this.sequence = sequence;
	}

	public Integer getPublishFlag() {
		return publishFlag;
	}

	public void setPublishFlag(Integer publishFlag) {
		this.publishFlag = publishFlag;
	}

	public List<DataModelItemVO> getDataModelItemVos() {
		return dataModelItemVos;
	}

	public void setDataModelItemVos(List<DataModelItemVO> dataModelItemVos) {
		this.dataModelItemVos = dataModelItemVos;
	}

	public List<DataModelVO> getChildren() {
		return children;
	}

	public void setChildren(List<DataModelVO> children) {
		this.children = children;
	}

	public String getTitle() {
		return modelName;
	}

	public Long getKey() {
		return key;
	}

	public void setKey(Long key) {
		this.key = key;
	}

}
